==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/kendra/kotlin/inputs/DataSourceCustomDocumentEnrichmentConfigurationInlineConfigurationConditionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.kendra.kotlin.inputs

import com.pulumi.aws.kendra.inputs.DataSourceCustomDocumentEnrichmentConfigurationInlineConfigurationConditionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property conditionDocumentAttributeKey The identifier of the document attribute used for the condition. For example, `_source_uri` could be an identifier for the attribute or metadata field that contains source URIs associated with the documents. Amazon Kendra currently does not support `_document_body` as an attribute key used for the condition.
 * @property conditionOnValue The value used by the operator. For example, you can specify the value 'financial' for strings in the `_source_uri` field that partially match or contain this value. See condition_on_value.
 * @property operator The condition operator. For example, you can use `Contains` to partially match a string. Valid Values: `GreaterThan` | `GreaterThanOrEquals` | `LessThan` | `LessThanOrEquals` | `Equals` | `NotEquals` | `Contains` | `NotContains` | `Exists` | `NotExists` | `BeginsWith`.
 */
public data class DataSourceCustomDocumentEnrichmentConfigurationInlineConfigurationConditionArgs(
    public val conditionDocumentAttributeKey: Output<String>,
    public val conditionOnValue:
    Output<DataSourceCustomDocumentEnrichmentConfigurationInlineConfigurationConditionConditionOnValueArgs>? =
        null,
    public val `operator`: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.kendra.inputs.DataSourceCustomDocumentEnrichmentConfigurationInlineConfigurationConditionArgs> {
    override fun toJava():
        com.pulumi.aws.kendra.inputs.DataSourceCustomDocumentEnrichmentConfigurationInlineConfigurationConditionArgs =
        com.pulumi.aws.kendra.inputs.DataSourceCustomDocumentEnrichmentConfigurationInlineConfigurationConditionArgs.builder()
            .conditionDocumentAttributeKey(conditionDocumentAttributeKey.applyValue({ args0 -> args0 }))
            .conditionOnValue(conditionOnValue?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .`operator`(`operator`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DataSourceCustomDocumentEnrichmentConfigurationInlineConfigurationConditionArgs].
 */
@PulumiTagMarker
public class DataSourceCustomDocumentEnrichmentConfigurationInlineConfigurationConditionArgsBuilder
internal constructor() {
    private var conditionDocumentAttributeKey: Output<String>? = null

    private var conditionOnValue:
        Output<DataSourceCustomDocumentEnrichmentConfigurationInlineConfigurationConditionConditionOnValueArgs>? =
        null

    private var `operator`: Output<String>? = null

    /**
     * @param value The identifier of the document attribute used for the condition. For example, `_source_uri` could be an identifier for the attribute or metadata field that contains source URIs associated with the documents. Amazon Kendra currently does not support `_document_body` as an attribute key used for the condition.
     */
    @JvmName("bkplrxbxigtjyitd")
    public suspend fun conditionDocumentAttributeKey(`value`: Output<String>) {
        this.conditionDocumentAttributeKey = value
    }

    /**
     * @param value The value used by the operator. For example, you can specify the value 'financial' for strings in the `_source_uri` field that partially match or contain this value. See condition_on_value.
     */
    @JvmName("kgcyqqjhhfuauuuo")
    public suspend
    fun conditionOnValue(`value`: Output<DataSourceCustomDocumentEnrichmentConfigurationInlineConfigurationConditionConditionOnValueArgs>) {
        this.conditionOnValue = value
    }

    /**
     * @param value The condition operator. For example, you can use `Contains` to partially match a string. Valid Values: `GreaterThan` | `GreaterThanOrEquals` | `LessThan` | `LessThanOrEquals` | `Equals` | `NotEquals` | `Contains` | `NotContains` | `Exists` | `NotExists` | `BeginsWith`.
     */
    @JvmName("fvuqwjccvwbqkhic")
    public suspend fun `operator`(`value`: Output<String>) {
        this.`operator` = value
    }

    /**
     * @param value The identifier of the document attribute used for the condition. For example, `_source_uri` could be an identifier for the attribute or metadata field that contains source URIs associated with the documents. Amazon Kendra currently does not support `_document_body` as an attribute key used for the condition.
     */
    @JvmName("jjfchedhqabbvmaj")
    public suspend fun conditionDocumentAttributeKey(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.conditionDocumentAttributeKey = mapped
    }

    /**
     * @param value The value used by the operator. For example, you can specify the value 'financial' for strings in the `_source_uri` field that partially match or contain this value. See condition_on_value.
     */
    @JvmName("vjdrhqleheluycch")
    public suspend
    fun conditionOnValue(`value`: DataSourceCustomDocumentEnrichmentConfigurationInlineConfigurationConditionConditionOnValueArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.conditionOnValue = mapped
    }

    /**
     * @param argument The value used by the operator. For example, you can specify the value 'financial' for strings in the `_source_uri` field that partially match or contain this value. See condition_on_value.
     */
    @JvmName("dtqiowjjqbnebwmd")
    public suspend
    fun conditionOnValue(argument: suspend DataSourceCustomDocumentEnrichmentConfigurationInlineConfigurationConditionConditionOnValueArgsBuilder.() -> Unit) {
        val toBeMapped =
            DataSourceCustomDocumentEnrichmentConfigurationInlineConfigurationConditionConditionOnValueArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.conditionOnValue = mapped
    }

    /**
     * @param value The condition operator. For example, you can use `Contains` to partially match a string. Valid Values: `GreaterThan` | `GreaterThanOrEquals` | `LessThan` | `LessThanOrEquals` | `Equals` | `NotEquals` | `Contains` | `NotContains` | `Exists` | `NotExists` | `BeginsWith`.
     */
    @JvmName("xcxvosorbbiabjpj")
    public suspend fun `operator`(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`operator` = mapped
    }

    internal fun build():
        DataSourceCustomDocumentEnrichmentConfigurationInlineConfigurationConditionArgs =
        DataSourceCustomDocumentEnrichmentConfigurationInlineConfigurationConditionArgs(
            conditionDocumentAttributeKey = conditionDocumentAttributeKey ?: throw
                PulumiNullFieldException("conditionDocumentAttributeKey"),
            conditionOnValue = conditionOnValue,
            `operator` = `operator` ?: throw PulumiNullFieldException("operator"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/kendra/kotlin/inputs/DataSourceCustomDocumentEnrichmentConfigurationInlineConfigurationConditionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.kendra.kotlin.inputs

import com.pulumi.aws.kendra.inputs.DataSourceCustomDocumentEnrichmentConfigurationInlineConfigurationConditionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property conditionDocumentAttributeKey The identifier of the document attribute used for the condition. For example, `_source_uri` could be an identifier for the attribute or metadata field that contains source URIs associated with the documents. Amazon Kendra currently does not support `_document_body` as an attribute key used for the condition.
 * @property conditionOnValue The value used by the operator. For example, you can specify the value 'financial' for strings in the `_source_uri` field that partially match or contain this value. See condition_on_value.
 * @property operator The condition operator. For example, you can use `Contains` to partially match a string. Valid Values: `GreaterThan` | `GreaterThanOrEquals` | `LessThan` | `LessThanOrEquals` | `Equals` | `NotEquals` | `Contains` | `NotContains` | `Exists` | `NotExists` | `BeginsWith`.
 */
public data class DataSourceCustomDocumentEnrichmentConfigurationInlineConfigurationConditionArgs(
    public val conditionDocumentAttributeKey: Output<String>,
    public val conditionOnValue: Output<DataSourceCustomDocumentEnrichmentConfigurationInlineConfigurationConditionConditionOnValueArgs>? =
        null,
    public val `operator`: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.kendra.inputs.DataSourceCustomDocumentEnrichmentConfigurationInlineConfigurationConditionArgs> {
    override fun toJava(): com.pulumi.aws.kendra.inputs.DataSourceCustomDocumentEnrichmentConfigurationInlineConfigurationConditionArgs =
        com.pulumi.aws.kendra.inputs.DataSourceCustomDocumentEnrichmentConfigurationInlineConfigurationConditionArgs.builder()
            .conditionDocumentAttributeKey(conditionDocumentAttributeKey.applyValue({ args0 -> args0 }))
            .conditionOnValue(conditionOnValue?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .`operator`(`operator`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DataSourceCustomDocumentEnrichmentConfigurationInlineConfigurationConditionArgs].
 */
@PulumiTagMarker
public class DataSourceCustomDocumentEnrichmentConfigurationInlineConfigurationConditionArgsBuilder
internal constructor() {
    private var conditionDocumentAttributeKey: Output<String>? = null

    private var conditionOnValue:
        Output<DataSourceCustomDocumentEnrichmentConfigurationInlineConfigurationConditionConditionOnValueArgs>? =
        null

    private var `operator`: Output<String>? = null

    /**
     * @param value The identifier of the document attribute used for the condition. For example, `_source_uri` could be an identifier for the attribute or metadata field that contains source URIs associated with the documents. Amazon Kendra currently does not support `_document_body` as an attribute key used for the condition.
     */
    @JvmName("jrclnotpcjfrchtl")
    public suspend fun conditionDocumentAttributeKey(`value`: Output<String>) {
        this.conditionDocumentAttributeKey = value
    }

    /**
     * @param value The value used by the operator. For example, you can specify the value 'financial' for strings in the `_source_uri` field that partially match or contain this value. See condition_on_value.
     */
    @JvmName("nttsuhfmhcselnhe")
    public suspend fun conditionOnValue(`value`: Output<DataSourceCustomDocumentEnrichmentConfigurationInlineConfigurationConditionConditionOnValueArgs>) {
        this.conditionOnValue = value
    }

    /**
     * @param value The condition operator. For example, you can use `Contains` to partially match a string. Valid Values: `GreaterThan` | `GreaterThanOrEquals` | `LessThan` | `LessThanOrEquals` | `Equals` | `NotEquals` | `Contains` | `NotContains` | `Exists` | `NotExists` | `BeginsWith`.
     */
    @JvmName("eopfwdahdqsgcbyc")
    public suspend fun `operator`(`value`: Output<String>) {
        this.`operator` = value
    }

    /**
     * @param value The identifier of the document attribute used for the condition. For example, `_source_uri` could be an identifier for the attribute or metadata field that contains source URIs associated with the documents. Amazon Kendra currently does not support `_document_body` as an attribute key used for the condition.
     */
    @JvmName("inrxtepqwxhtmyvt")
    public suspend fun conditionDocumentAttributeKey(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.conditionDocumentAttributeKey = mapped
    }

    /**
     * @param value The value used by the operator. For example, you can specify the value 'financial' for strings in the `_source_uri` field that partially match or contain this value. See condition_on_value.
     */
    @JvmName("btfcyinbcypddtls")
    public suspend fun conditionOnValue(`value`: DataSourceCustomDocumentEnrichmentConfigurationInlineConfigurationConditionConditionOnValueArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.conditionOnValue = mapped
    }

    /**
     * @param argument The value used by the operator. For example, you can specify the value 'financial' for strings in the `_source_uri` field that partially match or contain this value. See condition_on_value.
     */
    @JvmName("aymkqxlrlwpjlxle")
    public suspend fun conditionOnValue(argument: suspend DataSourceCustomDocumentEnrichmentConfigurationInlineConfigurationConditionConditionOnValueArgsBuilder.() -> Unit) {
        val toBeMapped =
            DataSourceCustomDocumentEnrichmentConfigurationInlineConfigurationConditionConditionOnValueArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.conditionOnValue = mapped
    }

    /**
     * @param value The condition operator. For example, you can use `Contains` to partially match a string. Valid Values: `GreaterThan` | `GreaterThanOrEquals` | `LessThan` | `LessThanOrEquals` | `Equals` | `NotEquals` | `Contains` | `NotContains` | `Exists` | `NotExists` | `BeginsWith`.
     */
    @JvmName("cujghkywgxbbyyuf")
    public suspend fun `operator`(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`operator` = mapped
    }

    internal fun build(): DataSourceCustomDocumentEnrichmentConfigurationInlineConfigurationConditionArgs =
        DataSourceCustomDocumentEnrichmentConfigurationInlineConfigurationConditionArgs(
            conditionDocumentAttributeKey = conditionDocumentAttributeKey ?: throw
                PulumiNullFieldException("conditionDocumentAttributeKey"),
            conditionOnValue = conditionOnValue,
            `operator` = `operator` ?: throw PulumiNullFieldException("operator"),
        )
}
